@@ -41,12 +41,21 @@ class GosTest(unittest.TestCase):
 
     @classmethod
     def setUpClass(cls):
+        # 確認是否有之前沒刪除完的 tmp 資料夾
+        folderId = cls._TEST_FOLDER_ID
+        result = os.getFiles(folderId)
+        for r in result:
+            if r['name'].startswith("tmp"):
+                os.remove(os.path.join(cls._TEST_FOLDER, r['name']))
+        
+        # 創測試資料
         tmpName = 'tmp' + str(datetime.datetime.now().microsecond)
 
         cls.TEST_FOLDER = os.path.join(cls.TEST_FOLDER, tmpName)
         os.makedirs(cls.TEST_FOLDER)
         os.copy(os.path.join(cls._TEST_FOLDER, 'plane.jpg'),
                 os.path.join(cls.TEST_FOLDER, 'plane.jpg'))
+        
 
     @classmethod
     def tearDownClass(cls):
@@ -82,7 +91,7 @@ class GosTest(unittest.TestCase):
     def testGetFiles(self):
         folderId = self._TEST_FOLDER_ID
         result = os.getFiles(folderId)
-        
+
         # 只能有三個檔案，plane.jpg、Hello.txt 與 testcase 會臨時創出來的 temp cls.TEST_FOLDER
         self.assertIn(len(result), [3,])
 
